%define major     15
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

Name:           aspell
Version:        0.60.8
Release:        %mkrel 6
Summary:        A Free and Open Source interactive spelling checker program
Group:          Text tools
License:        LGPL
URL:            http://aspell.net/
Source0:        https://ftp.gnu.org/gnu/aspell/%{name}-%{version}.tar.gz

#
# Security Patches
# P100 -> ...
#
# CVE-2019-25051: https://github.com/google/oss-fuzz-vulns/blob/main/vulns/aspell/OSV-2020-521.yaml
Patch100:      0718b375425aad8e54e1150313b862e4c6fd324a.patch
BuildRequires: gettext-devel
BuildRequires: ncursesw-devel
%if !%{bootstrap}
Requires:      aspell-dictionary
%endif

%description
GNU Aspell is a Free and Open Source spell checker designed to eventually
replace Ispell. It can either be used as a library or as an independent
spell checker.
Its main feature is that it does a much better job of coming up with possible
suggestions than just about any other spell checker out there for the English
language, including Ispell and Microsoft Word. It also has many other technical
enhancements over Ispell such as using shared memory for dictionaries and
intelligently handling personal dictionaries when more than one Aspell process
is open at once.


%files -f %{name}.lang
%doc README TODO
%{_bindir}/aspell*
%{_bindir}/run-with-aspell
%{_bindir}/word-list-compress
%{_bindir}/precat
%{_bindir}/preunzip
%{_bindir}/prezip
%{_bindir}/prezip-bin
%{_libdir}/aspell-0.60
%{_libdir}/aspell
%doc %{_infodir}/aspell*
%doc %{_mandir}/man1/*.1*

#----------------------------------------------------------------------

%package -n     %{libname}
Summary:        Shared library files for aspell
Group:          Text tools
Recommends:     aspell-dictionary

%description -n %{libname}
Shared library files for the aspell package.

%files -n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}

#----------------------------------------------------------------------

%package -n     %{develname}
Summary:        Development files for aspell
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       libaspell-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{libname}-devel
Conflicts:      libpspell4-devel

%description -n %{develname}
Development headers, and files for development from the aspell package.


%files -n %{develname}
%{_bindir}/pspell-config
%{_includedir}/*
%{_libdir}/libaspell.so
%{_libdir}/libpspell.so

#----------------------------------------------------------------------

%package        manual
Summary:        Manual for aspell
Group:          Text tools

%description    manual
This package contains a manual for aspell.

GNU Aspell is a Free and Open Source spell checker designed to eventually
replace Ispell. It can either be used as a library or as an independent
spell checker.


%files manual
%doc manual/*

#----------------------------------------------------------------------

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

# Provides symlink for configures that mean to match aspell on %%_libdir/aspell
pushd %{buildroot}%{_libdir}
    ln -sf aspell-0.60 aspell
popd

%find_lang %{name}


%changelog
* Fri Mar 18 2022 umeabot <umeabot> 0.60.8-6.mga9
+ Revision: 1797569
- Mageia 9 Mass Rebuild

* Tue Jul 27 2021 neoclust <neoclust> 0.60.8-5.mga9
+ Revision: 1737964
- Add P100: Fixes CVE-2019-25051 (mga#29294)

* Tue Nov 03 2020 wally <wally> 0.60.8-4.mga8
+ Revision: 1642455
- drop multiarch support

* Wed Feb 19 2020 umeabot <umeabot> 0.60.8-3.mga8
+ Revision: 1542560
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jan 05 2020 shlomif <shlomif> 0.60.8-2.mga8
+ Revision: 1476722
- Try to fix MGA#26004 - recommend aspell-dictionary.

* Sun Oct 13 2019 daviddavid <daviddavid> 0.60.8-1.mga8
+ Revision: 1452604
- new version: 0.60.8

* Tue Sep 10 2019 shlomif <shlomif> 0.60.7-1.mga8
+ Revision: 1439463
- New version 0.60.7

* Fri Sep 21 2018 umeabot <umeabot> 0.60.6.1-12.mga7
+ Revision: 1294644
- Mageia 7 Mass Rebuild

* Tue May 01 2018 wally <wally> 0.60.6.1-11.mga7
+ Revision: 1224317
- build with ncursesw

* Sun Sep 24 2017 cjw <cjw> 0.60.6.1-10.mga7
+ Revision: 1158682
- add buildrequires: gettext-devel
- add fixes from upstream for gcc 7

* Mon Feb 01 2016 umeabot <umeabot> 0.60.6.1-9.mga6
+ Revision: 930234
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.60.6.1-8.mga5
+ Revision: 745906
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.60.6.1-7.mga5
+ Revision: 677920
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.60.6.1-6.mga4
+ Revision: 522133
- Mageia 4 Mass Rebuild

* Fri Feb 08 2013 luigiwalser <luigiwalser> 0.60.6.1-5.mga3
+ Revision: 397101
- remove obsolete pre script

* Fri Jan 11 2013 umeabot <umeabot> 0.60.6.1-4.mga3
+ Revision: 346193
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 0.60.6.1-3.mga3
+ Revision: 325122
- clean .spec

* Wed Dec 07 2011 fwang <fwang> 0.60.6.1-2.mga2
+ Revision: 178046
- drop .la files
+ tv <tv>
- new release
+ dmorgan <dmorgan>
- Bump release
- disable bootstrap now
- Rebuild as previous build failed on the BS
- Bump release
- Add aspell requires on the bootstrap
- Remove mdv macros
- imported package aspell
+ spuhler <spuhler>
- Increased release
-Release: %%mkrel 8
  +Release: %%mkrel 1
-BuildRoot: %%{_tmppath}/%%{name}-%%{version}-root


* Mon Nov 29 2010 Oden Eriksson <oeriksson@mandriva.com> 0.60.6-8mdv2011.0
+ Revision: 603188
- rebuild

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0.60.6-7mdv2010.1
+ Revision: 518902
- rebuild

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 0.60.6-6mdv2010.0
+ Revision: 413042
- rebuild

* Mon Mar 23 2009 Götz Waschk <waschk@mandriva.org> 0.60.6-5mdv2009.1
+ Revision: 360644
- rebuild

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.60.6-4mdv2009.1
+ Revision: 316457
- rebuild

* Mon Aug 25 2008 Emmanuel Andry <eandry@mandriva.org> 0.60.6-3mdv2009.0
+ Revision: 275998
- apply devel policy
- check major

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0.60.6-2mdv2009.0
+ Revision: 264320
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed May 21 2008 Oden Eriksson <oeriksson@mandriva.com> 0.60.6-1mdv2009.0
+ Revision: 209743
- 0.60.6 (may fix build with gcc43)

  + Thierry Vignaud <tv@mandriva.org>
    - fix description-line-too-long

* Fri Jan 11 2008 Thierry Vignaud <tv@mandriva.org> 0.60.5-7mdv2008.1
+ Revision: 148465
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Sep 18 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.60.5-6mdv2008.0
+ Revision: 89572
- rebuild

* Mon May 21 2007 Helio Chissini de Castro <helio@mandriva.com> 0.60.5-5mdv2008.0
+ Revision: 29447
- Play nice with shell during installs

* Fri May 18 2007 Helio Chissini de Castro <helio@mandriva.com> 0.60.5-4mdv2008.0
+ Revision: 28334
- Back to old libdir 0.60 as pointed by Thierry Vignaud, To keep compat with other apps configures
  that looks in plain aspell directory, keep a symlink to aspell.

* Fri Apr 20 2007 Helio Chissini de Castro <helio@mandriva.com> 0.60.5-3mdv2008.0
+ Revision: 16358
- Install proper aspell files under aspell dir, bit under a versionated dir. Is clear that in 2008 we
  will not have 2 aspell on machines, and having such versionated dir made all packages depending on
  aspell add a patch on their configures to detect, instead of standard aspell. Now things is a little
  bit more sane, as we fix the parent source, not the dependencies.
- Remove unused patch


* Mon Jan 29 2007 Olivier Blin <oblin@mandriva.com> 0.60.5-2mdv2007.0
+ Revision: 115140
- split manual in aspell-manual package

* Thu Jan 18 2007 Jérôme Soyer <saispo@mandriva.org> 0.60.5-1mdv2007.1
+ Revision: 110162
- New release 0.60.5

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.60.4-3mdv2007.1
+ Revision: 74494
- Import aspell

* Thu Sep 07 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.60.4-3mdv2007.0
- Add Patch to fix extra qualification

* Sat May 13 2006 Stefan van der Eijk <stefan@eijk.nu> 0.60.4-2mdk
- rebuild for sparc

* Tue Nov 29 2005 Thierry Vignaud <tvignaud@mandriva.com> 0.60.4-1mdk
- new release

* Thu Aug 11 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.60.3-2mdk
- fix rpmlint errors ( dot ended summary )

* Wed Jun 29 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.60.3-1mdk
- new release

* Fri Feb 25 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.60.2-2mdk
- multiarch

* Mon Dec 20 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 0.60.2-1mdk
- 0.60.2

* Wed Dec 01 2004 Pablo Saratxaga <pablo@mandrakesoft.com> 0.60.1.1-1mdk
- updated version

* Fri Sep 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.50.5-3mdk
- Enable libtoolize
- Remove patch0, regenerate build environment instead

* Fri Jun 04 2004 Laurent Montel <lmontel@mandrakesoft.com> 0.50.5-2mdk
- Rebuild against new gcc

* Fri May 14 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.50.5-1mdk
- Release 0.50.5
- Regenreate patch0 (partially merged)

* Fri May 14 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.50.4.1-2mdk
- Rebuild

* Mon Mar 08 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.50.4.1-1.2mdk
- really fix amd64 build

* Mon Mar 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.50.4.1-1.1mdk
- amd64 build fixes

